@@ -8,9 +8,10 @@ import os
 import shutil
 import logging
 import urllib.request
+import uuid
 from hyperopt import hp
 
-from xtlib import utils
+from xtlib import utils, xt_vault
 from xtlib import errors
 from xtlib import constants
 from xtlib import file_utils
@@ -140,9 +141,12 @@ class AzureML(BackendBase):
         '''
         # we need to move our cwd (default working dir is blob-mapped and slow)
         # as of 10/21/2020, ITP recommends we use "/var/tmp" until they disable the NFS mount for $HOME
-        # guid = str(uuid.uuid4())
         # job_home = "$HOME/{}".format(guid)
-        job_home = "/var/tmp"
+
+        # add a GUID as of Aug-21-2022, to make a .xt dir unique and work around unexplainable problems with MNT directories on singularity
+        # guid = str(uuid.uuid4())
+        # job_home = "/var/tmp/" + guid
+        job_home = "/var/tmp/"
         cwd = "{}/.xt/cwd".format(job_home)
 
         use_gpu = args["use_gpu"]
@@ -467,6 +471,50 @@ class AzureML(BackendBase):
 
         return vars
 
+    def get_azure_cred(self):
+        from azureml.core.authentication import TokenAuthentication
+        from azure.identity import InteractiveBrowserCredential, AuthenticationRecord, TokenCachePersistenceOptions 
+
+        token = None
+
+        def get_the_token_func(audience):
+            nonlocal token
+
+            if not token:
+                value = self.config.get_vault()
+                credential, _ = value.get_creds_core("auto")
+
+                # # open the serialized azure authentication record (contains no secrets)
+                # dir_name = file_utils.get_xthome_dir()
+                # fn = dir_name + "/azure_cred_cache.txt"        
+                # deserialized_record = None
+
+                # if os.path.exists(fn):
+                #     with open(fn, "rt") as infile:
+                #         cred_json = infile.read()
+                #         deserialized_record = AuthenticationRecord.deserialize(cred_json)
+
+                # cpo = TokenCachePersistenceOptions()
+                # credential = InteractiveBrowserCredential(cache_persistence_options=cpo,
+                #     authentication_record=deserialized_record)
+
+                # if not deserialized_record:
+                #     # force authentication
+                #     record = credential.authenticate()
+
+                #     # serialize to our cache
+                #     cred_json = record.serialize()
+                #     with open(fn, "wt") as outfile:
+                #         outfile.write(cred_json)
+
+                yyy = credential.get_token("https://management.azure.com/.default")
+                token = yyy.token
+            return token
+
+        amlauth = TokenAuthentication(get_the_token_func)
+        amlauth.get_token()
+        return amlauth
+
     def get_aml_ws(self, ws_name):
 
         creds = self.config.get("external-services", ws_name, suppress_warning=True)
@@ -475,17 +523,16 @@ class AzureML(BackendBase):
 
         subscription_id = self.config.get_required_service_property(creds, "subscription-id", ws_name)
         resource_group = self.config.get_required_service_property(creds, "resource-group", ws_name)
+        ws_type = self.config.get_required_service_property(creds, "type", ws_name)
 
-        #from azureml.core.authentication import ServicePrincipalAuthentication
-        # ws_ex = ws_name + "-ex"
-        # svc_pr = None
-        # if self.config.name_exists(section, ws_ex):
-        #     client_id = self.config.get(section, ws_ex, "client-id")
-        #     tenant_id = self.config.get(section, ws_ex, "tenant-id")
-        #     client_secret = self.config.get(section, ws_ex, "client-secret")
-        #     svc_pr = ServicePrincipalAuthentication(tenant_id=tenant_id, service_principal_id=client_id, service_principal_password=client_secret)
+        # cred = None
+        # if ws_type == "singularity":
+        #     console.print("authenticating with auzre... ", end="")
+        #     cred = self.get_azure_cred()
+        #     console.print("done")
+        cred = self.get_azure_cred()
 
-        ws = Workspace(subscription_id, resource_group, ws_name)     # , auth=svc_pr)
+        ws = Workspace.get(name=ws_name, subscription_id=subscription_id, resource_group=resource_group, auth=cred) 
         return ws
 
     def get_aml_ws_sizes(self, aml_ws_name):
