@@ -207,7 +207,7 @@ def get_box_list(core, job_id=None, explicit_boxes_only=False, box=None, pool=No
             service_type = config.get_service_type(service_name)
 
             if service_type in ["batch", "philly", "aml", "itp", "singularity"]:
-                num_boxes = pool_info["nodes"] 
+                num_boxes = utils.safe_value(pool_info, "nodes", 1)
                 if num_boxes == 0:
                     errors.config_error("no nodes specified for Azure {} compute".format(service_type))
 
