@@ -252,7 +252,12 @@ class CmdCore():
         # compute number of runs for this node
         node_run_count = 1+runs_per_node if node_index < plus_one_count else runs_per_node
 
-        first_run_index = runs_per_node*node_index
+        # computing the first_run_index is a tad tricky
+        if node_index < plus_one_count:
+            first_run_index = (1+runs_per_node)*node_index
+        else:
+            first_run_index = (1+runs_per_node)*plus_one_count + runs_per_node*(node_index-plus_one_count)
+
         last_run_index = first_run_index + node_run_count - 1
 
         return first_run_index, last_run_index
@@ -279,12 +284,22 @@ class CmdCore():
         first_run_index, last_run_index = \
             self.compute_run_indexes_for_node(total_run_count, node_count, node_index)
 
+        # # TEMP (turn off ASAP)
+        # # test self.compute_run_indexes_for_node()
+        # fri, lri = self.compute_run_indexes_for_node(total_run_count, node_count, 0)
+        # assert fri==0 
+        # fri, lri = self.compute_run_indexes_for_node(total_run_count, node_count, node_count-1)
+        # assert lri==total_run_count-1
+
         context.first_run_index = first_run_index
         context.last_run_index = last_run_index
 
         # only apply run delays for jobs with multiple runs
         context.max_delay = args["max_run_delay"] if total_run_count > 1 else 0
 
+        # expand this on the compute node (where we know the node/run assignment in case of dynamic schedule)
+        context.display_name = args["display_name"]
+
         context.ws = workspace
         context.working_dir = working_dir
         context.exper_name = exper_name
@@ -314,6 +329,7 @@ class CmdCore():
         context.xt_cmd = args["xt_cmd"]     # log our full cmd to support correct rerun's
         context.run_script = run_specs["run_script"]
         context.parent_script = run_specs["parent_script"]
+        context.num_dgd_seeds = args["num_dgd_seeds"]
 
         compute_def = args["compute_def"]
         context.username = self.config.get("general", "username")
@@ -370,6 +386,11 @@ class CmdCore():
         context.search_type = args["search_type"]
         context.option_prefix = args["option_prefix"]
 
+        schedule = args["schedule"]
+        if context.search_type == "ccd":
+            schedule = "dynamic"
+        context.schedule = schedule
+
         context.restart = False
         context.concurrent = args["concurrent"]
         context.xtlib_capture = args["xtlib_upload"]
@@ -490,9 +511,11 @@ class CmdCore():
         fn_run_context = bootstrap_dir + "/" + constants.FN_RUN_CONTEXT 
         file_utils.ensure_dir_exists(file=fn_run_context)
         
+
         box_runs = job_runs[0]
-        cfc = self.create_context_file_core(box_runs, 0, job_id, using_hp,  
-            app_info=None, exper_name=experiment, args=args)
+        cfc = self.create_context_file_core(box_runs, 0, job_id, using_hp, app_info=None, exper_name=experiment, 
+            args=args)
+            
         context_data = cfc["runs"][0]
         
         text = json.dumps(context_data, indent=4)
