@@ -389,8 +389,6 @@ class Trainer():
             print("---> tb_path=", tb_path)
             self.run = XTRun(xt_logging=logging, aml_logging=logging, checkpoints_enabled=logging, tensorboard_path=tb_path)
 
-            #utils.debug_break()
-
             if args.tag_job:
                 self.run.tag_job( {"plotted_metric": "test_acc"} )
 
@@ -498,21 +496,37 @@ class Trainer():
             
         return mnt_output_dir, local_output_dir, data_dir
 
+    def print_env_vars(self):
+        max_value_len = 150
+
+        print("  env vars:")
+        keys = list(os.environ.keys())
+        keys.sort()
+        skip_count = 0
+
+        for key in keys:
+            if key.startswith("E_"):
+                # skip massive amounts of ITP-injected env vars
+                skip_count += 1
+                continue
+
+            if skip_count:
+                print("    ===> <{:,} E_XXX environment variables skipped>".format(skip_count))
+                skip_count = 0
+                
+            value = os.environ[key]
+
+            if len(value) > max_value_len:
+                value = value[0:max_value_len] + "..."
+                
+            print("    {}: {}".format(key, value))
 
     def print_settings(self, args):
         print("--- miniMnist settings ---")
         print("  command-line args:", sys.argv)
 
         if args.env_vars:
-            print("  env vars:")
-            keys = list(os.environ.keys())
-            keys.sort()
-
-            for key in keys:
-                value = os.environ[key]
-                if len(value) > 100:
-                    value = value[0:100] + "..."
-                print("    {}: {}".format(key, value))
+            self.print_env_vars()
 
         print("  cwd: " + os.getcwd())
         print("  python: " + sys.version.replace("\n", " "))
@@ -584,8 +598,6 @@ class Trainer():
         return model, device, mnt_output_dir, local_output_dir
 
     def apply_runset_file(self, args, fn):
-        #utils.debug_break()
-
         fn = os.path.abspath(fn)
         with open(fn, "rt") as infile:
             yd = yaml.safe_load(infile)  
@@ -726,15 +738,14 @@ class Trainer():
             outfile.write("This is a file that should be omitted from AFTER upload\n")
             outfile.write("end of junk file\n")
 
-        if run and run.store.mongo:
+        if run and run.store.database:
             # ensure we close all logging
             print("miniMNST: mongo call stats")
-            run.store.mongo.print_call_stats()
+            run.store.database.print_call_stats()
             run.close()
 
 def main():
     started = time.time()
-    #utils.debug_break()
 
     trainer = Trainer()
     trainer.run()
