@@ -63,6 +63,9 @@ run control/information:
 
     (*) not yet completed
 '''     
+
+DEFAULT_FROM_COMPUTE = None
+
 class ImplCompute(ImplBase):
     def __init__(self, config, store=None):
         super(ImplCompute, self).__init__()
@@ -344,6 +347,17 @@ class ImplCompute(ImplBase):
                             last_status_shown = simple_status
 
                         if new_text:
+                            if "$status: " in new_text:
+                                index = new_text.index("$status: ")
+                                index2 = new_text.index("\n", index)
+
+                                if index2:
+                                    msg = new_text[index+9:index2]
+                                else:
+                                    msg = new_text[index+9:]
+                                # change title of our console window to show the status msg
+                                os.system("title " + msg)
+
                             if node_count > 1:
                                 # prepend each new line with node_id
                                 prefix = node_id + ": "
@@ -863,6 +877,7 @@ class ImplCompute(ImplBase):
     @hidden("after-dirs", default="$after-files.after-dirs", help="the files and directories to upload after the run completes")
     @hidden("after-omit", default="$after-files.after-omit", help="the files and directories to omit from after uploading")
     @flag("after-upload", default="$after-files.after-upload", help="when true, the after files are upload when the run completes")
+    @option("aml_compute", type=str, default=DEFAULT_FROM_COMPUTE, help="specifies the name of the AML compute resource for the job")
     @hidden("capture_setup_cmds", type=bool, default="$logging.capture-setup-cmds", help="specifies if some setup cmds should output to a log file")
     @option("cluster", help="the name of the Philly cluster to be used")
     @hidden("code-dirs", default="$code.code-dirs", help="paths to the main code directory and dependent directories")
@@ -895,6 +910,7 @@ class ImplCompute(ImplBase):
     @hidden("fn_generated_config", default="$hyperparameter-search.fn-generated-config", type=str, help="the name for the generated HP config file")
     @hidden("framework", default="$aml-options.framework", help="the name of the framework to be installed for the run (pytorch, tensorflow, chainer)")
     @hidden("fw-version", default="$aml-options.fw-version", help="the framework version number")
+    @option("display-name", default="$general.display-name", type=str, help="the singularity display name for this job")
     @option("goal-metric", default="$hyperparameter-search.goal-metric", type=float, help="goal for primary metrics (stops CCD hp search when reached)")
     #@hidden("grok-server", default="$logging.grok-server", help="the ip address of the grok-server to be used for mirroring")
     @flag("hold", help="when True, the Azure Pool (VM's) are held open for debugging)")
@@ -902,7 +918,7 @@ class ImplCompute(ImplBase):
     @flag("jupyter-monitor", help="when True, a Jupyter notebook is created to monitor the run")
     @hidden("log", default="$logging.log", help="specifes if run-related events should be logged")
     @hidden("log-reports", default="$logging.log-reports", help="specifies if CPU, GPU, and MEMORY reports should be included in setup log")
-    @option("low-pri", type=bool, help="when true, use low-priority (preemptable) nodes for this job")
+    @option("low-pri", type=bool, default=DEFAULT_FROM_COMPUTE, help="when true, use low-priority (preemptable) nodes for this job")
     @option("max-passes", default="$hyperparameter-search.max-passes", type=int, help="used to limit number of passes over hyperparameters in hp search")
     @option("max-minutes", default="$hyperparameter-search.max-minutes", type=int, help="the maximum number of minutes the run can execute before being terminated")
     @hidden("max-seconds", type=int, default="$aml-options.max-seconds", help="the maximum number of seconds this run will execute before being terminated")
@@ -923,8 +939,10 @@ class ImplCompute(ImplBase):
     @flag("multi-commands"   , help="the script file contains multiple run commands (one per line)")
     @option("node-delay", type=str, default="$general.node-delay", help="maximum time to randomly delay start of node execution")
     @option("node-repeat", type=int, help="the number of times to repeat each hyperparameter set on each node")
+    @hidden("node-script-path", type=str, default="$code.node-script-path", help="relative path to script on computing node")
     @option("nodes", type=int, help="the number of normal (non-preemptable) nodes to allocte for this run")
     @option("nowrap", type=bool, help="when true, don't generate a wrapper script for XT setup; run user script directly")
+    @option("num-dgd-seeds", type=int, default="$hyperparameter-search.num-dgd-seeds", help="the number of random HP configurations used to initialize the DGD search")
     @hidden("option-prefix", default="$hyperparameter-search.option-prefix", help="the prefix to be used for specifying hyperparameter options to the script")
     @option("parent-script", type=str, help="path of script used to initialize the target for repeated runs of primary script")
     @hidden("pip-freeze", default="$logging.pip-freeze", help="when true, installed pip packges are included in the setup log")
@@ -938,8 +956,10 @@ class ImplCompute(ImplBase):
     @option("schedule", default="static", values=["static", "dynamic"], help="specifies if runs are pre-assigned to each node or allocate on demand")
     @option("search-type", values=["random", "grid", "bayesian", "dgd", "ccd"], default="$hyperparameter-search.search-type", help="the type of hyperparameter search to perform")
     @option("seed", default=None, help="the random number seed that can be used for reproducible HP searches")
+    @option("service", type=str, default=DEFAULT_FROM_COMPUTE, help="the name of the xt config-specified compute service to use for this job")
     @option("setup", type=str, help="the name of the setup entry to use with the target (from one of the entries in the config file [setups] section")
-    @option("sku", help="the name of the Philly SKU to be used (e.g, 'G1')")
+    @option("sku", default=DEFAULT_FROM_COMPUTE, type=str, help="the name of the Philly SKU to be used (e.g, 'G1')")
+    @option("sla", type=str, default=DEFAULT_FROM_COMPUTE, values=["premium", "standard", "basic"], help="the level of anti-preemption service for the job (Singularity)")
     @hidden("slack-factor", default="$early-stopping.slack-factor", type=float, help="(bandit only) specified as a ratio, the delta between this eval and the best performing eval")
     @hidden("slack-amount", default="$early-stopping.slack-amount", type=float, help="(bandit only) specified as an amount, the delta between this eval and the best performing eval")
     @option("sleep-on-exit", type=str, default="0", help="the amount of time to sleep (e.g., '45m'), before controller exits it's process")
@@ -953,7 +973,7 @@ class ImplCompute(ImplBase):
     @option("username", default="$general.username", help="the username to log as the author of this run")
     # @hidden("user-managed", type=bool, default="$aml-options.user-managed", help="if true, it implies that the local machine or VM will be managed by the user")
     @option("vc", help="the name of the Philly virtual cluster to be used")
-    @option("vm-size", help="the type of Azure VM computer to run on")
+    @option("vm-size", type=str, default=DEFAULT_FROM_COMPUTE, help="the type of Azure VM computer to run on")
     @hidden("working-dir", default="$code.working-dir", type=str, help="the run's working directory, relative to the code directory")
     @option("workspace", default="$general.workspace", type=str, help="the workspace to create and manage the run")
     @flag("xtlib-upload", default="$code.xtlib-upload", help="when True, local source code for xtlib is included in the source code snapshot ")
