@@ -18,10 +18,28 @@ from xtlib import file_utils
 from xtlib import store_utils
 from xtlib import run_helper
 
-job_info_props = {"_id": 1, "compute": 1, "concurrent": 1, "exper_name": 1, "hold": 1, "job_id": 1, "job_num": 1,
-    "job_guid": 1, "job_secret": 1, "node_count": 1, "primary_metric": 1, "run_count": 1, "repeat": 1, 
-    "schedule": 1, "search_type": 1, "search_style": 1, "username": 1, "xt_cmd": 1, "started": 1,
-    "pool_info": 1, "service_job_info": 1, "ws_name": 1, "sleep_on_exit": 1}
+'''
+To add a new job info column (defined at job submit time):
+    - add it to the following job_helper.py dicts:
+        - add to "job_info_props" dict
+        - add to "user_to_actual" dict (recommend using same name for friendly name)
+        - add to "std_cols_desc" dict (describes what the column holds)
+
+    - add it to the following odbc.py dicts:
+        - the job_info sub-dict in _init_core_tables()
+
+    - add it to runner.py:
+        - in the "dd" dict that is passed to the call: self.store.log_job_info()
+
+'''
+
+# NEW COLS: sla, low_pri, vm_size, sku, service_name, service_type, aml_compute, compute_target, num_dgd_seeds
+# LEGACY column for old jobs: "compute" (logged as "target")
+
+job_info_props = {"_id": 1, "aml_compute": 1, "compute": 1, "compute_target": 1,"concurrent": 1, "exper_name": 1, "hold": 1, "job_id": 1, "job_num": 1,
+    "job_guid": 1, "job_secret": 1, "low_pri": 1, "node_count": 1, "num_dgd_seeds": 1, "primary_metric": 1, "run_count": 1, "repeat": 1, 
+    "schedule": 1, "search_type": 1, "search_style": 1, "service_name": 1, "service_type": 1, "username": 1, "xt_cmd": 1, "started": 1,
+    "pool_info": 1, "service_job_info": 1, "sku": 1, "sla": 1, "ws_name": 1, "sleep_on_exit": 1, "vm_size": 1}
 
 job_stats_props = {"job_status": 1, "completed_runs": 1, "error_runs": 1, "running_runs": 1, 
     "running_nodes": 1, "total_runs": 1, "db_retries": 1, "storage_retries": 1,
@@ -115,7 +133,7 @@ def build_filter_part(fd, args, arg_name, store_name):
 
 def build_job_filter_dict(ws_name, job_list, user_to_actual, builder, workspace, args):
     fd = {}
-    option_filters = ["experiment", "target", "service_type", "username", "status"]   # "application"
+    option_filters = ["experiment", "compute_target", "service_type", "username", "status"]   # "application"
 
     if job_list:
         # filter by specified job names
@@ -161,12 +179,17 @@ def build_job_filter_dict(ws_name, job_list, user_to_actual, builder, workspace,
 
     return fd
 
-user_to_actual = {"cluster": "pool_info.cluster", "docker": "pool_info.environment", "experiment": "exper_name",
-    "hold": "hold", "job": "job_id","job_num": "job_num", "low_pri": "pool_info.low-pri", 
-    "node_count": "node_count", "primary_metric": "primary_metric", "queue": "pool_info.queue", 
-    "repeat": "repeat", "search": "search_type", "service_type": "pool_info.service", 
-    "sku": "pool_info.sku", "runs": "run_count", "search_style": "search_style", "started": "started", "target": "compute", "username": "username", 
-    "vc": "pool_info.vc", "vm_size": "pool_info.vm-size", "workspace": "ws_name",  
+# NEW COLS: sla, low_pri, vm_size, sku, service_name, service_type, aml_compute, compute_target, num_dgd_seeds
+# LEGACY column for old jobs: "compute" (logged as "target")
+
+user_to_actual = {"aml_compute": "aml_compute", "cluster": "cluster", "compute_target": "compute_target", 
+    "docker": "environment", "experiment": "exper_name",
+    "hold": "hold", "job": "job_id","job_num": "job_num", "low_pri": "low_pri", "num_dgd_seeds": "num_dgd_seeds",
+    "node_count": "node_count", "primary_metric": "primary_metric", "queue": "queue", 
+    "repeat": "repeat", "search": "search_type", "service_name": "service_name", "service_type": "service_type", 
+    "sku": "sku", "runs": "run_count", "search_style": "search_style", "sla": "sla", 
+    "started": "started", "username": "username", "target": "compute",
+    "vc": "vc", "vm_size": "vm_size", "workspace": "ws_name",  
     "hparams": "hparams", "tags": "tags", "sleep_on_exit": "sleep_on_exit", 
 
 
@@ -179,7 +202,9 @@ user_to_actual = {"cluster": "pool_info.cluster", "docker": "pool_info.environme
 
 std_cols_desc = {
     # the key here is the USER friendly name (not the physical name)
+    "aml_compute": "the AML compute name specified in the target for this job",
     "cluster": "the Philly Cluster that the job ran on",
+    "compute_target": "the name of the compute target specified for this job",
     "docker": "the Docker environment specified for this job",
     "experiment": "the experiment associated with the job",
     "hold": "if the Azure Batch pool for this job was requested to be held open after runs were completed",
@@ -187,14 +212,17 @@ std_cols_desc = {
     "job_num": "the sort compatible, numeric portion of the job_id",
     "low_pri": "if the nodes requested for this job were specified as preemptable",
     "node_count": "the number of compute nodes requested for this job",
+    "num_dgd_seeds": "the number of random HP configurations used to initialize the DGD search",
     "primary_metric": "the name of the metric used for hyperparameter searching",
     "queue": "the Philly queue that the job was submitted to",
     "repeat": "the repeat count specified for the job",
     "runs": "the total number of runs for the job",
     "search": "the type of hyperparameter search requested",
     "search_style": "describes how search is being accomplished (one of: static, dynamic, multi, repeat, single)",
-    "service_type": "the service type of the target",
+    "service_name": "the name of the service specified in the target for this job",
+    "service_type": "the service type of the target specified for this job",
     "sku": "the machine type requested for this job",
+    "sla": "the singularity service level specified for this job",
     "sleep_on_exit": "the amount of time controller should wait before it's normal process exist",
     "started": "the datetime when the job was started",
     "target": "the name of the compute target the job was submitted to",
@@ -473,7 +501,7 @@ def get_job_info_with_backend(store, core, workspace, job_id, node_index):
 
 def get_service_node_info_with_backend(store, core, workspace, job_id, node_index):
     
-    backend, job_info = get_job_info_with_backend(store, core, workspace, job_id)
+    backend, job_info = get_job_info_with_backend(store, core, workspace, job_id, node_index)
     service_info_by_node = job_info["service_info_by_node"]  
 
     node_id = utils.node_id(node_index)
