@@ -22,6 +22,15 @@ from xtlib import errors
 from xtlib import pc_utils
 from xtlib import constants
 from xtlib.hp_set import HpSetFormatter
+from xtlib.helpers import html_writer
+
+def format_value(fmt, value):
+    if value is None:
+        text = ""
+    else:
+        text = fmt.format(value)
+
+    return text
 
 class ReportBuilder():
     def __init__(self, config=None, store=None):
@@ -200,7 +209,7 @@ class ReportBuilder():
         for key in record.keys():
             if key in subs:
                 value = record[key]
-                if value:
+                if isinstance(value, dict):
                     self.build_avail_list(col_dict, value, prefix=key + ".")
             else:
                 col_dict[prefix + key] = 1
@@ -468,6 +477,12 @@ class ReportBuilder():
 
         avail_list = list(col_dict.keys())
 
+        # if we are computing averages of column(s), ensure the base name of those columns ar in user_columns 
+        # user only needs to specify the xxx-mean or xxx-err names, so include the base name to ensure metrics are carried thru
+        mean_cols = utils.safe_value(args, "mean")
+        if mean_cols:
+            user_columns += mean_cols
+
         # get list of user-requested columns
         all_user_columns = self.get_user_columns(user_columns, args)
 
@@ -493,6 +508,11 @@ class ReportBuilder():
         reverse = utils.safe_value(args, "reverse")
         first = utils.safe_value(args, "first")
         last = utils.safe_value(args, "last")
+        all = utils.safe_value(args, "all")
+
+        if all:
+            first = None
+            last = None
 
         if mean_cols:
             # produce new mean-calculated columns (new records)
@@ -513,12 +533,28 @@ class ReportBuilder():
         #             user_columns.remove(col)
 
         def _set_or_append(values, value, index): 
-            values[index] = value if index > -1 else values.append(value)
+            if index > -1:
+                values[index] = value
+            else:
+                values.append(value)
 
+        '''
+        The --hp_set_display controls how a hp-set is incorporated into your list runs report.  A hp-set
+        is a collection of all the hyperparameters in a run.  You can include only the hyperparameters whose
+        values changed in 1 or more runs, or all of the hyperparameters.
+
+            changed:                adds a JSON column for the changed hparams
+            full:                   adds a JSON column for all of the hparams
+            simple:                 adds a column for the name of the hp_set (e.g., hp_set_1)
+            columns:                adds a column for each changed hparam
+            user-columns:           adds a column for each hparam specified by the user (run-reports, named-columns, etc.)
+            simple_plus_columns:    adds a column for each changed hparam, and a colum for the hp-set name
+        '''
         if hp_set_display == "changed":
             _set_or_append(user_columns, "hp_set:$hpset_changed", hp_set_index)
 
         if hp_set_display == "simple" or hp_set_display == "simple_plus_columns":
+            # "simpl"
             _set_or_append(user_columns, "hp_set:$hpset_simple", hp_set_index)
 
         if hp_set_display == "full":
@@ -528,18 +564,32 @@ class ReportBuilder():
             if self.hp_set_formatter.hp_common_set:
                 # for each run record, convert hp_set column into new columns in the record 
                 for record in records:
-                    hp_set_str = record["hp_set"]
-                    hp_set = self.hp_set_formatter.format_hpset_changed(hp_set_str)
+                    if "hp_set" in record:
+                        hp_set_str = record["hp_set"]
+                        hp_set = self.hp_set_formatter.format_hpset_changed(hp_set_str)
 
-                    for hp, value in hp_set.items():
-                        full_hp_name = "hparams." + hp
-                        record[full_hp_name] = value
+                        for hp, value in hp_set.items():
+                            full_hp_name = "hparams." + hp
+                            record[full_hp_name] = value
+
+                        if hp_set_display == "columns":
+                            del record["hp_set"]
+
+        if hp_set_display == "user-columns":
+            if self.hp_set_formatter.hp_common_set:
+                # for each run record, convert hp_set column into new columns in the record 
+                for record in records:
+                    if "hp_set" in record:
+                        hp_set_str = record["hp_set"]
+                        hp_set = self.hp_set_formatter.parse_and_sort_hp_set(hp_set_str)
+
+                        for hp, value in hp_set.items():
+                            full_hp_name = "hparams." + hp
+                            if full_hp_name in user_columns:
+                                record[full_hp_name] = value
 
-                    if hp_set_display == "columns":
                         del record["hp_set"]
 
-                # add "hparams.*" to ensure we display all of the hyperparameters
-                #user_columns.append("hparams.*")
 
         avail_list, actual_cols, user_col_args  = self.get_avail_actual_user_cols(records, user_columns, args)
 
@@ -718,12 +768,12 @@ class ReportBuilder():
         return text
 
     def build_formatted_table(self, records, avail_cols=None, col_list=None, max_col_width=None, 
-        report_type="run-reports", group_by=None, number_groups=False):
+        report_type="run-reports", group_by=None, number_groups=False, indent=None, print_report=False, copy_as_html=False):
         '''
         Args:
             records:        a list of dict entries containing data to format
             avail_cols:     list of columns (unique dict keys found in records)
-            col_list:    list of columns to be used for report (strict subset of 'avail_cols')
+            col_list:       list of columns to be used for report (strict subset of 'avail_cols')
             report_type:    a dotted path to the report definition in the XT config file
 
         Processing:
@@ -836,7 +886,7 @@ class ReportBuilder():
                         if "$" in user_fmt:
                             value_str, align = self.xt_custom_format(user_fmt, value)
                         else:
-                            value_str = user_fmt.format(value)
+                            value_str = format_value(user_fmt, value)
 
                     elif isinstance(value, float):
                         if col == "metrics.best-eval-acc":
@@ -931,6 +981,20 @@ class ReportBuilder():
             text, row_count = self.generate_report(col_infos, records, right_align_num_cols, uppercase_hdr_cols, truncate_with_ellipses, 
                 col_space, duration_col_names, time_col_names, significance, max_fixed_length, precision)
 
+        if indent:
+            text = "\n".join([indent + line for line in text.split("\n")])
+
+        if print_report:
+            console.print(text)
+
+        if copy_as_html:
+            writer = html_writer.HtmlWriter()
+            html = writer.write(text)
+            
+            from xtlib.helpers import clipboard
+            with clipboard.Clipboard() as cb:
+                cb.set_contents("HTML FORMAT", html)
+
         return text, row_count
 
     def create_mean_records_core(self, records, mean_cols, group_by):
@@ -1216,13 +1280,13 @@ class ReportBuilder():
                                 # custom XT formatting
                                 value, align = self.xt_custom_format(user_fmt, value)
                             else:
-                                value = user_fmt.format(value)   
+                                value = format_value(user_fmt, value)
 
                             # now treat as string that must fit into col_width
                             str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
                             #value = value if value else ""
                             value = "" if value is None else value
-                            text += str_fmt.format(value)
+                            text += format_value(str_fmt, value)
 
                         elif isinstance(value, float):
 
@@ -1235,21 +1299,21 @@ class ReportBuilder():
                                 # use FIXED POINT formatting
                                 float_fmt = "{:" + align + str(col_width) + "." + str(precision) + "f}"
 
-                            text += float_fmt.format(value)
+                            text += format_value(float_fmt, value)
 
                         elif isinstance(value, bool):
                             bool_fmt = "{!r:" + align + str(col_width) + "}"
-                            text += bool_fmt.format(value)
+                            text += format_value(bool_fmt, value)
                         elif isinstance(value, int):
                             int_fmt = "{:" + align + str(col_width) + "d}"
-                            text += int_fmt.format(value)
+                            text += format_value(int_fmt, value)
                         else:
                             if col == "sku":
                                 dummy = 3
                             # ensure value is a string
                             value = "" if value is None else str(value)
                             str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
-                            text += str_fmt.format(value)
+                            text += format_value(str_fmt, value)
 
             except BaseException as ex:
                 console.print("Exception formatting col={}: {}".format(col, ex))
