@@ -20,7 +20,8 @@ from xtlib.console import console
 from xtlib.helpers import file_helper
 from xtlib.helpers.feedbackParts import feedback as fb
 
-run_info_props = {"_id": 1, "app_name": 1, "box_name": 1, "compute": 1, "create_time": 1, "description": 1, "exper_name": 1,
+run_info_props = {"_id": 1, "app_name": 1, "box_name": 1, "compute": 1, "create_time": 1, "description": 1, 
+    "display_name": 1, "exper_name": 1,
     "from_ip": 1, "from_computer_name": 1, "hp_set": 1, "is_child": 1, "is_parent": 1, "is_outer": 1, "job_id": 1, 
     "node_index": 1, "path": 1, "repeat": 1, "script": 1, "run_index": 1, "run_name": 1, "run_num": 1, "run_guid": 1,
     "search_style": 1, "search_type": 1, "service_type": 1, "sku": 1, "username": 1, "ws_name": 1, 
@@ -183,7 +184,7 @@ def remove_run_stats(dd: dict):
     return run_stats
 
 user_to_actual = {"box": "box_name", "created": "create_time", "child": "is_child", "cluster": "cluster",
-    "description": "description", "experiment": "exper_name", "exit_code": "exit_code", 
+    "description": "description", "display_name": "display_name", "experiment": "exper_name", "exit_code": "exit_code", 
     "from_host": "from_computer_name", "from_ip": "from_ip", 
     "guid": "run_guid", "hp_set": "hp_set", "job": "job_id", "last_time": "last_time",
     "node_index": "node_index", "outer": "is_outer", "parent": "is_parent", "path": "path", 
@@ -213,6 +214,7 @@ std_cols_desc = {
     "ended": "when the run execution ended",
     "db_retries": "the total number of database retries performed by the runs of this node",
     "description": "the user specified description associated with the run",
+    "display_name": "the singularity display name for this run",
     "duration": "how long the run has been executing",
     "end_id": "a unique serial number assigned to each run when it has ended",
     "ended": "when the run completed",
@@ -525,7 +527,15 @@ def list_runs(store, config, args, compare=False):
         if compare:
             # filter cols to those that are different
             diff_cols = get_different_cols(records)
+            
+            # remove any cols that user want to hide
+            omit_cols = args["omit_columns"]
+            for omit in omit_cols:
+                if omit in diff_cols:
+                    diff_cols.remove(omit)
+
             args["columns"] = diff_cols 
+            user_columns = utils.get_user_columns(args["columns"], report_type, config)
 
         #avail_list = list(user_to_actual.keys())
         lines, row_count, was_exported = builder.build_report(records, user_columns=user_columns, report_type=report_type, args=args)
@@ -565,25 +575,8 @@ def list_runs(store, config, args, compare=False):
             else:
                 console.print("no matching runs found")
 
-def get_run_records(store, ws_name, run_names, fields_dict=None):
-    ''' return run records for specified run names'''
-
-    db = store.get_database()
-
-    filter_dict = {}
-    filter_dict["run_name"] = {"$in": run_names}
-
-    if not fields_dict:
-        # by default, get everything but the log records
-        #fields_dict = {"log_records": 0}
-        fields_dict = {"run_info": 1, "run_stats": 1}
-
-    run_records = db.get_info_for_runs(ws_name, filter_dict, fields_dict)
-
-    return run_records
-
 def get_run_record(store, workspace, run_name, fields_dict = None):
-    run_records = get_run_records(store, workspace, [run_name], fields_dict)
+    run_records = get_run_records_simple(store, workspace, [run_name], fields_dict)
     if not run_records:
         errors.store_error("Run {} does not exist in workspace {}".format(run_name, workspace))
     rr = run_records[0]
@@ -798,6 +791,9 @@ def build_metrics_sets(records, steps=None, merge=False, metrics=None, timebase=
                     actual = alias_to_actual[key]
                     utils.rename_dict_key(dd, key, actual)
         
+        # sort items by keys to ensure matches by all-key-string 
+        dd = dict(sorted(dd.items()))
+
         if step_name is None:
             if constants.STEP_NAME in dd:
                 step_name = dd[constants.STEP_NAME]
@@ -1164,3 +1160,81 @@ def is_run_name(name):
 
     return is_valid
 
+def get_run_records_simple(store, ws_name, run_names, fields_dict=None):
+    ''' return run records for specified run names'''
+
+    db = store.get_database()
+
+    filter_dict = {}
+    filter_dict["run_name"] = {"$in": run_names}
+
+    if not fields_dict:
+        # by default, get everything but the log records
+        #fields_dict = {"log_records": 0}
+        fields_dict = {"run_info": 1, "run_stats": 1}
+
+    run_records = db.get_info_for_runs(ws_name, filter_dict, fields_dict)
+
+    return run_records
+
+def get_run_records(job_id, run_ids,  metric_names=None, filter_dict=None, fields_dict=None, include_hparams=False, include_log_records=None, 
+    workspace_name=None, config=None):
+
+    # JIT import to prevent circular references
+    from xtlib.storage.store import Store
+    from xtlib.helpers.xt_config import get_merged_config
+
+    if config is None:
+        config = get_merged_config()
+    store = Store(config=config)
+
+    if not workspace_name:
+        workspace_name = config.get("general", "workspace")
+
+    # how to filter records
+    if not filter_dict:
+        filter_dict = {}
+    
+    filter_dict = {"job_id": job_id}
+    if run_ids:
+        filter_dict["run_name"] = {"$in": run_ids}
+
+    if not fields_dict:
+        # return these fields
+        fields_dict = {"status": 1, "job_id": 1, "run_name": 1, "last_time": 1}
+
+    if include_hparams:
+        fields_dict["hparams"] = 1
+
+    if metric_names:
+        full_metric_names = ["metrics." + metric for metric in metric_names]
+
+        for name in full_metric_names:
+            #filter_dict[name] = {"$exists": True}
+            fields_dict[name] = 1
+    
+    fetch_logs = include_log_records or metric_names
+    run_records = store.database.get_info_for_runs(workspace_name, filter_dict, fields_dict, include_log_records=fetch_logs)
+
+    if metric_names:
+        for record in run_records:
+            log_records = record["log_records"]
+            metric_sets = build_metrics_sets(log_records)
+            metrics_dict = {}
+
+            # for each metric name to plot
+            for metric_name in metric_names:
+                msr = [md["records"] for md in metric_sets if metric_name in md["keys"]]
+                if msr:
+                    values = msr[0]
+                    steps = [value["step"] for value in values]
+                    metric_values = [value[metric_name] for value in values]
+
+                    metrics_dict[metric_name] = {"steps": steps, "values": metric_values}
+
+            # update record
+            record["metrics_dict"] = metrics_dict
+            if not include_log_records:
+                del record["log_records"]
+
+    return run_records
