@@ -25,7 +25,7 @@ logger = logging.getLogger(__name__)
 class RunInfo():
     def __init__(self, run_name, workspace, cmd_parts, run_script, repeat, context, status, show_output=True, parent_name=None, 
         parent_prep_needed=False, mirror_close_func=None, node_id=None, run_index=None, max_delay=0,
-        store=None):
+        store=None, is_parent=False):
 
         if isinstance(repeat, str):
             repeat = int(repeat)
@@ -36,7 +36,7 @@ class RunInfo():
         self.cmd_parts = cmd_parts
         self.run_script = run_script
         self.repeat = repeat
-        self.is_parent = parent_name is None
+        self.is_parent = is_parent
         self.repeats_remaining = repeat if context.repeats_remaining is None else context.repeats_remaining 
         self.context = context
         self.status = status    
