@@ -3,6 +3,7 @@
 # Licensed under the MIT license.
 #
 # runner.py: code to prepare to build a run submission (shared code for all backends)
+import enum
 import os
 import sys
 import json
@@ -333,10 +334,13 @@ class Runner():
 
                 tag_dict = args["tags"]
 
+                display_name = args["display_name"]
+                display_name = utils.expand_xt_vars(display_name, run_id=run_name, args=args)
+
                 self.store.start_run_core(workspace, run_name=run_name, exper_name=exper_name, box_name=box_name, app_name=app_name, 
                     username=username, repeat=repeat, pool=pool, job_id=job_id, node_index=node_index, sku=sku,
                     description=description, aggregate_dest=aggregate_dest, path=path, compute=compute, service_type=service_type, 
-                    search_style=search_style, is_parent=is_parent, tag_dict=tag_dict)
+                    search_style=search_style, is_parent=is_parent, tag_dict=tag_dict, display_name=display_name)
 
             console.diag("create_run: after start_run")
 
@@ -412,7 +416,7 @@ class Runner():
 
         return runs_by_box, last_run
 
-    def adjust_script_dir(self, cmd_parts):
+    def adjust_script_dir(self, cmd_parts, node_script_path=None):
         '''
         NOTE: cmd_parts is modified directly.
         '''
@@ -435,9 +439,15 @@ class Runner():
                 if os.path.isfile(part):
                     # ensure the slashes in the path match targeted OS 
                     fixed_path = file_utils.fix_slashes(part, is_linux=dest_linux)
-                    parts[i] = fixed_path
-
                     script_dir = os.path.dirname(fixed_path)
+                    script_fn = os.path.basename(fixed_path)
+
+                    # adjust script_dir
+                    if node_script_path:
+                        parts[i] = node_script_path + "/" + script_fn
+                        script_dir = node_script_path
+                    else:                        
+                        parts[i] = fixed_path
                     found_script = True
 
         if not script_dir:
@@ -617,14 +627,13 @@ class Runner():
         code_dirs = args["code_dirs"]
         xtlib_capture = args["xtlib_upload"]
         code_omit = args["code_omit"]
+        node_script_path = args["node_script_path"]
         script_dir = None
 
         code_upload = args["code_upload"]
 
-        # new design: script dir must be relative and we don't touch it
-        # # this step should always be done so that script_dir is removed from cmd_parts
-        # script_dir = self.remove_script_dir_from_parts(cmd_parts)
-        script_dir = self.adjust_script_dir(cmd_parts)
+        # this figures out the node's path to the script 
+        script_dir = self.adjust_script_dir(cmd_parts, node_script_path)
 
         if code_upload:
             for i, code_dir in enumerate(code_dirs):
@@ -812,6 +821,9 @@ class Runner():
         node_count = len(boxes)
         args["node_count"] = node_count
 
+        args["job_id"] = job_id
+        experiment = utils.expand_xt_vars(experiment, job_runs=job_runs, args=args)
+
         # now that we have run names for all static run names for all nodes, we can adjust cmds (and before files) for using the controller
         if use_controller:
             # we will create 2 temp. controller files in the CURRENT DIRECTORY (that will be captured to JOB)
@@ -843,7 +855,6 @@ class Runner():
             args["model_local"] = model_local
 
         # ADJUST CMDS: this allows backend to write scripts to snapshot dir, if needed, as a way of adjusting/wrapping run commands
-        args["job_id"] = job_id
         self.backend.adjust_run_commands(job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args=args)
 
         # upload CODE from snapshot_dir
@@ -910,6 +921,7 @@ class Runner():
             xt_cmd = args["xt_cmd"]
             schedule = args["schedule"]
             concurrent = args["concurrent"]
+            num_dgd_seeds = utils.safe_value(args, "num_dgd_seeds")
 
             # this job property is used to ensure we don't exceed the specified # of runs when using repeat_count on each node
             dynamic_runs_remaining = None if search_style == "single" else total_run_count
@@ -920,9 +932,21 @@ class Runner():
 
             tag_dict = args["tags"]
 
+            # NEW COLS: sla, low_pri, vm_size, sku, service_name, service_type, aml_compute, compute_target, num_dgd_seeds
+    
             dd = {
                 # JOB_INFO: flat READONLY props (18)
-                "compute": compute, 
+                # new cols
+                "sla": utils.safe_value(compute_def, "sla"),
+                "low_pri": utils.safe_value(compute_def, "low-pri"),
+                "vm_size": utils.safe_value(compute_def, "vm-size"),
+                "sku": utils.safe_value(compute_def, "sku"),
+                "service_name": utils.safe_value(compute_def, "service"),
+                "service_type": utils.safe_value(args, "service_type"),
+                "aml_compute": utils.safe_value(compute_def, "compute"),
+                "compute_target": utils.safe_value(compute_def, "name"),
+
+                # old cols
                 "concurrent": concurrent,
                 "exper_name": experiment, 
                 "hold": args["hold"], 
@@ -931,6 +955,7 @@ class Runner():
                 "job_guid": job_guid, 
                 "job_secret": job_secret, 
                 "node_count": node_count, 
+                "num_dgd_seeds": num_dgd_seeds,
                 #"maximize_metric": args["maximize_metric"],      # not yet in DB/job_stats
                 "primary_metric": args["primary_metric"], 
                 "run_count": total_run_count, 
@@ -1235,10 +1260,10 @@ class Runner():
 
         return hparams if hparams else None
 
-    def fixup_script_in_cmd(self, cmd):
+    def fixup_script_in_cmd(self, cmd, node_script_path):
         cmd_parts = utils.cmd_split(cmd)
         
-        self.adjust_script_dir(cmd_parts)
+        self.adjust_script_dir(cmd_parts, node_script_path)
 
         # add "-u" for python cmds
         if len(cmd_parts) > 1 and cmd_parts[0].startswith("python") and cmd_parts[1] != "-u":
@@ -1273,6 +1298,7 @@ class Runner():
         
         lines = self.config.get("commands")
         multi_commands = args["multi_commands"]
+        node_script_path = args["node_script_path"]
  
         if lines:
             if using_hp:
@@ -1282,7 +1308,7 @@ class Runner():
 
             # commands specified in the config file
             args["multi_commands"] = True
-            cmds = [self.fixup_script_in_cmd(line) for line in lines]
+            cmds = [self.fixup_script_in_cmd(line, node_script_path) for line in lines]
 
         elif multi_commands:
             if using_hp:
@@ -1305,11 +1331,11 @@ class Runner():
 
                 runsets = data[constants.HPARAM_RUNSETS]
                 cmd = data[constants.HPARAM_COMMAND]
-                cmds = [self.fixup_script_in_cmd(cmd)]
+                cmds = [self.fixup_script_in_cmd(cmd, node_script_path)]
             else:
                 lines = file_utils.read_text_file(fn_script, as_lines=True)
                 lines = [line.strip() for line in lines if line and not line.strip().startswith("#")]
-                cmds = [self.fixup_script_in_cmd(line) for line in lines]
+                cmds = [self.fixup_script_in_cmd(line, node_script_path) for line in lines]
 
         return (cmds, runsets) if cmds else None
 
@@ -1573,14 +1599,18 @@ class Runner():
 def update_compute_def_from_cmd_options(compute_def, hold=False):
 
     compute_props = ["vm-size", "azure-image", "low-pri", "box-class", "docker", "setup", "boxes", 
-        "vc", "cluster", "queue", "sku", "nodes"]
+        "vc", "cluster", "queue", "sku", "nodes", "sla", "aml_compute", "service"]
 
     # apply any compute-def properties found in explicit args to compute_def
     explict_opts = qfe.get_explicit_options()
 
     for name, value in explict_opts.items():
         if name in compute_props:
-            compute_def[name] = value
+
+            if name == "aml_compute":
+                compute_def["compute"] = value
+            else:
+                compute_def[name] = value
 
     # if "hold" specified and queue not explictly set, queue defaults to "interactive"
     if hold and "cluster" in compute_def and "queue" not in explict_opts:
