@@ -908,8 +908,8 @@ class StoreV1():
 
     #---- LOW LEVEL ----
             
-    def list_blobs(self, container, blob_path, return_names=True):
-        return self.helper.list_blobs(container, blob_path, return_names=return_names)
+    def list_blobs(self, container, blob_path, return_names=True, recursive=True):
+        return self.helper.list_blobs(container, blob_path, return_names=return_names, recursive=recursive)
 
     # ---- RUN FILES ----
 
