@@ -41,7 +41,7 @@ class TensorboardReader():
         # get all blobs in the run's output dir
         #console.print("polling blob: container={}, path={}".format(self.ws_name, blob_path))
 
-        blobs = self.store.list_blobs(self.ws_name, blob_path, return_names=False)
+        blobs = self.store.list_blobs(self.ws_name, blob_path, return_names=False, recursive=True)
         #console.print("blob_names=", blobs)
         download_count = 0
 
