@@ -584,13 +584,16 @@ def zap_none(text):
         text = None
     return text
 
-def safe_cursor_value(cursor, name):
+def safe_cursor_value(cursor, name, get_all=False):
     value = None
     if cursor:
         records = list(cursor)
-        value = safe_value(records[0], name) if records else None
+        if get_all:
+            value = [safe_value(record, name) for record in records]
+        else:
+            value = safe_value(records[0], name) if records else None
     return value
-
+    
 def find_by_property(elements, prop, target):
     result = next((elem for elem in elements if prop in elem and elem[prop] == target), None) 
     return result
@@ -781,6 +784,8 @@ def shell_time_str_to_secs(text):
     return value
 
 def get_user_columns(columns_arg, report_name, config):
+    report_columns = config.get(report_name, "columns")
+
     if columns_arg:
         # name of a named-columns entry?
         columns = None
@@ -790,9 +795,21 @@ def get_user_columns(columns_arg, report_name, config):
 
         if not columns:
             # the actual column name(s)
-            columns = columns_arg
+            columns = []
+            for col in columns_arg:
+
+                found = False
+                for rcol in report_columns:
+                    if rcol.startswith(col):
+                        columns.append(rcol)
+                        found = True
+                        break
+
+                if not found:
+                    columns.append(col)
+
     else:
-        columns = config.get(report_name, "columns")
+        columns = report_columns
 
     return columns
 
@@ -800,4 +817,45 @@ def to_int_or_none(value):
     if value is not None:
         value = int(value)
 
-    return value
\ No newline at end of file
+    return value
+
+def expand_xt_vars(text, job_runs=None, run_id=None, job_id=None, node_index=0, args=None):
+    from xtlib import xt_dict
+    
+    if "$" in text:
+
+        if "$lastrun" in text:
+            last_run = xt_dict.get_xt_dict_value("last_run", "run0")
+            text = text.replace("$lastrun", last_run)
+
+        if "$lastjob" in text:
+            last_job = xt_dict.get_xt_dict_value("last_job", "job0")
+            text = text.replace("$lastjob", last_job)
+
+        if "$username" in text:
+            username = pc_utils.get_username()
+            text = text.replace("$username", username)
+
+        if "$job_id" in text:
+            job_id = args["job_id"]
+            text = text.replace("$job_id", job_id)
+
+        if "$run_id" in text:
+            # for now, use name of first parent run
+            if not run_id:
+                if job_runs:
+                    rd = job_runs[0][0] 
+                    run_id = rd["run_name"]
+                else:
+                    run_id = ""
+            text = text.replace("$run_id", run_id)
+
+        if "$node_id" in text:
+            node_id = "node{}".format(node_index)
+            text = text.replace("$node_id", node_id)
+
+        if "$node_index" in text:
+            text = text.replace("$node_index", node_index)
+
+    return text
+
